<?php
/**
 * Include and setup custom metaboxes and fields.
 *
 * @category Disk Player
 * @package  Metaboxes
 * @license  http://www.opensource.org/licenses/gpl-license.php GPL v2.0 (or later)
 * @link     https://github.com/webdevstudios/Custom-Metaboxes-and-Fields-for-WordPress
 */

if ( is_admin() ) {

    add_filter( 'cmb_meta_boxes_diskplayer', 'cmb_diskplayer_metaboxes' );
    /**
     * Define the metabox and field configurations.
     *
     * @param  array $meta_boxes
     * @return array
     */
    function cmb_diskplayer_metaboxes( array $meta_boxes ) {

        $opacity_options = array(
            '1.0' => '100%',
            '0.9' => '90%',
            '0.8' => '80%',
            '0.7' => '70%',
            '0.6' => '60%',
            '0.5' => '50%',
            '0.4' => '40%',
            '0.3' => '30%',
            '0.2' => '20%',
            '0.1' => '10%',
            '0.0' => '0%'
        );
        //array_reverse($opacity_options);

        // Start with an underscore to hide fields from custom fields list
        $prefix = '_dplayer_cmb_';


        /**
         * Disk Player Settings
         */
        $meta_boxes['settings_disk_player'] = array(
            'id'         => 'settings_disk_player',
            'title'      => __( 'Disk Player Settings', 'cmb' ),
            'pages'      => array( 'diskplayer', ), // Post type
            'context'    => 'side',
            'priority'   => 'default',
            'show_names' => true, // Show field names on the left
            'fields'     => array(
                array(
                    'name' => __( 'Default Image (80px X 80px)', 'cmb' ),
                    'desc' => __( 'Upload an image or enter a URL.', 'cmb' ),
                    'id'   => $prefix . 'default_image_poster',
                    'type' => 'file',
                ),
                array(
                    'name' => __( 'Display how many items for the scrollbar', 'cmb' ),
                    'id'   => $prefix . 'display_howmany_items',
                    'type' => 'text_small',
                    'default' => '3'
                ),
                array(
                    'name' => __( 'Display numbers', 'cmb' ),
                    'desc' => __( '', 'cmb' ),
                    'id'   => $prefix . 'display_numbers',
                    'type' => 'checkbox',
                ),
                array(
                    'name' => __( 'Autoplay', 'cmb' ),
                    'desc' => __( '', 'cmb' ),
                    'id'   => $prefix . 'autoplay',
                    'type' => 'checkbox',
                ),
                array(
                    'name' => __( 'Disable Header', 'cmb' ),
                    'desc' => __( '', 'cmb' ),
                    'id'   => $prefix . 'disable_header',
                    'type' => 'checkbox',
                ),
                array(
                    'name' => __( 'Disable Playlist', 'cmb' ),
                    'desc' => __( '', 'cmb' ),
                    'id'   => $prefix . 'disable_playlist',
                    'type' => 'checkbox',
                ),
                array(
                    'name' => __( 'Enable Skins', 'cmb' ),
                    'desc' => __( '', 'cmb' ),
                    'id'   => $prefix . 'enable_skins',
                    'type' => 'checkbox',
                ),
                array(
                    'name'    => __( 'Choose a Skin', 'cmb' ),
                    'desc'    => __( '', 'cmb' ),
                    'id'      => $prefix . 'skin',
                    'type'    => 'select',
                    'options' => array(
                        'dark' => __( 'Dark', 'cmb' ),
                        'light' => __( 'Light', 'cmb' ),
                        'grunge' => __( 'Grunge', 'cmb' ),
                        'stone' => __( 'Stone', 'cmb' ),
                    ),
                ),
                array(
                    'name' => __( 'General Colors', 'cmb' ),
                    'desc' => __( 'Settings below only work if you do NOT use a Skin option. If the "Enable Skins" field is checked, just ignore the options below.', 'cmb' ),
                    'id'   => $prefix . 'background_colors',
                    'type' => 'title',
                ),
                array(
                    'name'    => __( 'Title / Icons Color', 'cmb' ),
                    'desc'    => __( '', 'cmb' ),
                    'id'      => $prefix . 'title_icons_color',
                    'type'    => 'colorpicker',
                    'default' => '#ffffff'
                ),
                array(
                    'name'    => __( 'Title / Icons Color On Hover', 'cmb' ),
                    'desc'    => __( '', 'cmb' ),
                    'id'      => $prefix . 'title_icons_color_onhover',
                    'type'    => 'colorpicker',
                    'default' => '#999999'
                ),
                array(
                    'name'    => __( 'Font Color', 'cmb' ),
                    'desc'    => __( 'For the other texts in the interface.', 'cmb' ),
                    'id'      => $prefix . 'font_color',
                    'type'    => 'colorpicker',
                    'default' => '#999999'
                ),
                array(
                    'name'    => __( 'Sliders Color', 'cmb' ),
                    'desc'    => __( '', 'cmb' ),
                    'id'      => $prefix . 'sliders_color',
                    'type'    => 'colorpicker',
                    'default' => '#1862ae'
                ),
                array(
                    'name'    => __( 'Container Border Color', 'cmb' ),
                    'desc'    => __( '', 'cmb' ),
                    'id'      => $prefix . 'container_border_color',
                    'type'    => 'colorpicker',
                    'default' => '#111111'
                ),
                array(
                    'name'    => __( 'Header Color', 'cmb' ),
                    'desc'    => __( '', 'cmb' ),
                    'id'      => $prefix . 'header_color',
                    'type'    => 'colorpicker',
                    'default' => '#181818'
                ),
                array(
                    'name'    => __( 'Header Color Opacity', 'cmb' ),
                    'desc'    => __( '', 'cmb' ),
                    'id'      => $prefix . 'header_color_opacity',
                    'type'    => 'select',
                    'options' => $opacity_options,
                ),
                array(
                    'name'    => __( 'Interface Color', 'cmb' ),
                    'desc'    => __( '', 'cmb' ),
                    'id'      => $prefix . 'interface_color',
                    'type'    => 'colorpicker',
                    'default' => '#1e1e1e'
                ),
                array(
                    'name'    => __( 'Interface Color Opacity', 'cmb' ),
                    'desc'    => __( '', 'cmb' ),
                    'id'      => $prefix . 'interface_color_opacity',
                    'type'    => 'select',
                    'options' => $opacity_options,
                ),
                array(
                    'name'    => __( 'Interface Border Color', 'cmb' ),
                    'desc'    => __( 'border-top', 'cmb' ),
                    'id'      => $prefix . 'interface_border_color',
                    'type'    => 'colorpicker',
                    'default' => '#2D2D2D'
                ),
                array(
                    'name'    => __( 'Playlist Item Color', 'cmb' ),
                    'desc'    => __( '', 'cmb' ),
                    'id'      => $prefix . 'playlist_item_color',
                    'type'    => 'colorpicker',
                    'default' => '#111111'
                ),
                array(
                    'name'    => __( 'Playlist Item Color Opacity', 'cmb' ),
                    'desc'    => __( '', 'cmb' ),
                    'id'      => $prefix . 'playlist_item_color_opacity',
                    'type'    => 'select',
                    'options' => $opacity_options,
                ),
                array(
                    'name'    => __( 'Playlist Item Color On Hover', 'cmb' ),
                    'desc'    => __( '', 'cmb' ),
                    'id'      => $prefix . 'playlist_item_color_onhover',
                    'type'    => 'colorpicker',
                    'default' => '#222222'
                ),
                array(
                    'name'    => __( 'Playlist Item Border Color', 'cmb' ),
                    'desc'    => __( '', 'cmb' ),
                    'id'      => $prefix . 'playlist_item_border_color',
                    'type'    => 'colorpicker',
                    'default' => '#303030'
                ),
                array(
                    'name'    => __( 'Playlist Current Item Color', 'cmb' ),
                    'desc'    => __( '', 'cmb' ),
                    'id'      => $prefix . 'playlist_current_item_color',
                    'type'    => 'colorpicker',
                    'default' => '#2A2A2A'
                ),
                array(
                    'name'    => __( 'Scrollbar Color', 'cmb' ),
                    'desc'    => __( '', 'cmb' ),
                    'id'      => $prefix . 'scrollbar_color',
                    'type'    => 'colorpicker',
                    'default' => '#333333'
                ),
                array(
                    'name'    => __( 'BG Butttons Control Color', 'cmb' ),
                    'desc'    => __( '', 'cmb' ),
                    'id'      => $prefix . 'buttons_control_color',
                    'type'    => 'colorpicker',
                    'default' => '#000000'
                ),
                array(
                    'name'    => __( 'BG Toggles Color', 'cmb' ),
                    'desc'    => __( '', 'cmb' ),
                    'id'      => $prefix . 'toggles_color',
                    'type'    => 'colorpicker',
                    'default' => '#333333'
                ),
                array(
                    'name'    => __( 'Seek and Volume Bar', 'cmb' ),
                    'desc'    => __( '', 'cmb' ),
                    'id'      => $prefix . 'seek_volume_bar',
                    'type'    => 'colorpicker',
                    'default' => '#4A4A4A'
                ),
                array(
                    'name'    => __( 'Progress Bar', 'cmb' ),
                    'desc'    => __( '', 'cmb' ),
                    'id'      => $prefix . 'progress_bar',
                    'type'    => 'colorpicker',
                    'default' => '#999999'
                ),
                array(
                    'name'    => __( 'Other Elements Opacity', 'cmb' ),
                    'desc'    => __( 'Elements included: BG Butttons Control Color, BG Toggles Color, Scrollbar Color.', 'cmb' ),
                    'id'      => $prefix . 'other_elements_opacity',
                    'type'    => 'select',
                    'options' => $opacity_options,
                ),
                array(
                    'name' => __( 'Background Image', 'cmb' ),
                    'desc' => __( 'Use a background image for the player.', 'cmb' ),
                    'id'   => $prefix . 'background_image_player',
                    'type' => 'file',
                ),
            )
        );


        /**
         * Track Options
         */
        $meta_boxes['track_options_group'] = array(
            'id'         => 'track_options_group',
            'title'      => __( 'Add Tracks', 'cmb' ),
            'pages'      => array( 'diskplayer' ),
            'fields'     => array(
                array(
                        'id'          	=> $prefix . 'track_options_group',
                        'type'        	=> 'group',
                        'description' 	=> __( '', 'cmb' ),
                        'options'     	=> array(
                        'group_title'   => __( 'Track {#}', 'cmb' ), // {#} gets replaced by row number
                        'add_button'    => __( 'Add New Track', 'cmb' ),
                        'remove_button' => __( 'Remove Track', 'cmb' ),
                        'sortable'      => true, // beta
                    ),
                    // Fields array works the same, except id's only need to be unique for this group. Prefix is not needed.
                    'fields' => array(
                        array(
                            'name' => 'Track Title',
                            'id'   => 'track_title',
                            'type' => 'text',
                            // 'repeatable' => true, // Repeatable fields are supported w/in repeatable groups (for most types)
                        ),
                        array(
                            'name' => __( 'Artist', 'cmb' ),
                            'id'   => 'artist',
                            'type' => 'text'
                        ),
                        array(
                            'name' => __( 'MP3 File', 'cmb' ),
                            'description' => '',
                            'id'   => 'mp3_file',
                            'type' => 'file',
                        ),
                        array(
                            'name' => __( 'Image (80px X 80px)', 'cmb' ),
                            'description' => __( 'Optional. Use jpg or png. If not added, the default image will be used.', 'cmb' ),
                            'id'   => 'poster_image',
                            'type' => 'file',
                        ),
                        array(
                            'name' => __( 'Icon Download URL', 'cmb' ),
                            'description' => __( 'Optional.', 'cmb' ),
                            'id'   => 'download_url',
                            'type' => 'text'
                        ),
                        array(
                            'name' => __( 'Download Text', 'cmb' ),
                            'description' => __( 'Optional. Only if there is a URL for Download.', 'cmb' ),
                            'id'   => 'download_text',
                            'type' => 'text'
                        ),
                        array(
                            'name' => __( 'Icon Buy URL', 'cmb' ),
                            'description' => __( 'Optional.', 'cmb' ),
                            'id'   => 'buy_url',
                            'type' => 'text'
                        ),
                        array(
                            'name' => __( 'Buy Text', 'cmb' ),
                            'description' => __( 'Optional. Only if there is a URL for Buy.', 'cmb' ),
                            'id'   => 'buy_text',
                            'type' => 'text'
                        ),
                        array(
                            'name' => __( 'Icon Extra Info URL', 'cmb' ),
                            'description' => __( 'Optional.', 'cmb' ),
                            'id'   => 'extra_info_url',
                            'type' => 'text'
                        ),
                        array(
                            'name' => __( 'Extra Info Text', 'cmb' ),
                            'description' => __( 'Optional. Only if there is a URL for Extra Info.', 'cmb' ),
                            'id'   => 'extra_info_text',
                            'type' => 'text'
                        ),
                    ),
                ),
            ),
        );


        //Add other metaboxes as needed

        return $meta_boxes;
    }
}//is_adim()

//add_action( 'init', 'cmb_initialize_cmb_meta_boxes', 9999 );
/**
 * Initialize the metabox class.
 */
/*
function cmb_initialize_cmb_meta_boxes() {

	if ( ! class_exists( 'cmb_Meta_Box_Diskplayer' ) )
		require_once 'init.php';

}
*/